# Changelog

## [stormi-v0.2.4](https://github.com/pinellolab/stormi/compare/stormi-v0.2.3...stormi-v0.2.4) (2025-04-06)

### Bug Fixes

* **pyproject:** add jupyter metapackage for quarto ([5a4695b](https://github.com/pinellolab/stormi/commit/5a4695bb046b03399055bc66a5a341e2d83e2686))
* **pyproject:** add jupyter-cache for quarto ([ce21530](https://github.com/pinellolab/stormi/commit/ce21530b371127e639198a3fdad5131012698dca))
* **pyproject:** add quartodoc for quarto ([4824c73](https://github.com/pinellolab/stormi/commit/4824c7350b33438e5817d1e8a9cd937449117ec9))
* **pyproject:** remove transitive deps of jupyter ([5928aed](https://github.com/pinellolab/stormi/commit/5928aede975db09eddb5ded3f5098a8bc406079b))
* **pyproject:** rename interactive group to docs ([5f1d99b](https://github.com/pinellolab/stormi/commit/5f1d99bd005a95aa91115499322460c10cd3d86d))
